@@ -12,7 +12,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 0.9;
+our $VERSION  = 0.91;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -29,7 +29,7 @@ sub run {
     my @options;
     push @options, '-r' if $option{remote};
     push @options, '-a' if $option{all};
-    my $grep = $option{insensitive} ? "(?^i:$ARGV[0])" : $ARGV[0];
+    my $grep = $option{insensitive} ? "(?i:$ARGV[0])" : $ARGV[0];
 
     print join "\n", sort {_sorter()} grep {/$grep/} $workflow->git->branch(@options);
     print "\n";
@@ -54,7 +54,7 @@ git-branch-grep - grep for branch names
 
 =head1 VERSION
 
-This documentation refers to git-branch-grep version 0.9
+This documentation refers to git-branch-grep version 0.91
 
 =head1 SYNOPSIS
 
